# Estats
Estats is a python statistical package containing a set of method based upon energy statistics.

Energy statistics are a set of distribition-free non-parametrics methods first expounded by Gábor J. Székely and later on expanded by several others. They are of particular interest because they very little about the data generating distribution, merely that either its first or second moment is defined.

As well as being non-parametrc, energy statistics are valuable because its methods take no notice of the size of the data matrix $X$, since all its methods are functions of the distance matrix of $X$ not of $X$ itself, therefore there is no trouble in analysing multi-dimensional data.